# `aiida-sssp`

This is the official AiiDA plugin for the Standard Solid State Pseudopotential (SSSP) library.

[![Build Status](https://github.com/aiidateam/aiida-sssp/workflows/continuous-integration/badge.svg?event=push)](https://github.com/aiidateam/aiida-sssp/actions)
[![Docs status](https://readthedocs.org/projects/aiida-sssp/badge)](http://aiida-sssp.readthedocs.io/)
[![PyPI version](https://badge.fury.io/py/aiida-sssp.svg)](https://badge.fury.io/py/aiida-sssp)
[![PyPI pyversions](https://img.shields.io/pypi/pyversions/aiida-sssp.svg)](https://pypi.python.org/pypi/aiida-sssp/)
